/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without 
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */
 
/*****************************************************************************
 * Description: wrapper protocol global include file                         *
 * Author:      Pierpaolo Fumagalli <ianosh@iname.com>                       *
 * Version:     $Revision: 1.10 $                                            *
 *****************************************************************************/
#include "jserv.h"
#include "stdio.h"

/*****************************************************************************
 * Structures definition                                                     *
 *****************************************************************************/
typedef struct wrapper_property wrapper_property;
typedef struct wrapper_property_handler wrapper_property_handler;
typedef struct wrapper_config wrapper_config;
typedef struct wrapper_property_list_node wrapper_property_list_node;

struct wrapper_property {
    char *name;
    char *value;
    wrapper_property *next;
};

struct wrapper_property_handler {
    char *name;
    char *(*routine) (wrapper_config *cfg, char *value);
};

/* for a basic linked list */
struct wrapper_property_list_node {
    char * name;
    wrapper_property_list_node *next;
};

struct wrapper_config {
    char *bin;
    wrapper_property_list_node *binparam;
    char *class;
    char *classparam;
    wrapper_property *environment;
    jserv_config *config;
};


/*****************************************************************************
 * Some defined values and our defaults                                      *
 *****************************************************************************/
#ifdef WIN32
#define WRAPPER_PATH_SEPARATOR ';'
#define WRAPPER_DEFAULT_BIN "C:\\JDK\\BIN\\JAVA.EXE"
#define WRAPPER_DEFAULT_PATH NULL /* Evaluated thru GetWindows/SystemDir API */
#else /* ifdef WIN32 */
#define WRAPPER_PATH_SEPARATOR ':'
#define WRAPPER_DEFAULT_BIN "/usr/bin/java"
#define WRAPPER_DEFAULT_PATH "/bin:/usr/bin:/usr/local/bin"
#endif /* ifdef WIN32 */
#define WRAPPER_DEFAULT_CLASS "org.apache.jserv.JServ"
#define WRAPPER_DEFAULT_BINPARAM NULL
#define WRAPPER_DEFAULT_CLASSPARAM "\0"

/* ========================================================================= */
/* Our list of variables */
extern wrapper_property_handler wrapper_handlers[];
extern wrapper_config *wrapper_data;
extern pool *wrapper_pool;

/*****************************************************************************
 * Procedure pointers                                                        *
 *****************************************************************************/
int wrapper_parse(wrapper_config *cfg);
int wrapper_create(wrapper_config *cfg);
int wrapper_destroy(wrapper_config *cfg);
int wrapper_cleanup(jserv_config *cfg);
int wrapper_check_restart_time_ok();
int wrapper_restart_delay(void);
void wrapper_standalone_startup(void);
void wrapper_standalone_process(void);
int wrapper_shutdown_core(wrapper_config *cfg);
void wrapper_restart_failed();
void wrapper_restart_succeeded();
int wrapper_restart_want_debug_data();
